@@ -10,7 +10,8 @@ import tornado.httpclient as httpclient
 from jupyter_server.utils import url_path_join
 from datetime import datetime
 
-JWT_PATH = 'jwt.txt'
+JWT_PATH = '/yq/jwt.txt'
+JWT_HEADER = os.getenv('JWT_HEADER', default='userid-token')
 
 
 def get_jwt():
@@ -20,7 +21,7 @@ def get_jwt():
             jwt.close()
             return out
     except OSError:
-        app_log.error('Failed to read a JWT.')
+        app_log.debug('JWT is not created yet or failed to be fetched.')
         return None
 
 
@@ -37,14 +38,14 @@ class YqKfIdentity(APIHandler):
         jwt = get_jwt()
 
         if jwt is None or has_expired(jwt, alg='RS256'):
-            if "userid-token" in headers:
+            if JWT_HEADER in headers:
                 with open(JWT_PATH, 'w') as out:
-                    out.write(headers["userid-token"])
+                    out.write(headers[JWT_HEADER])
                     out.close()
             else:
                 app_log.warn('There is no JWT token in the headers')
                 self.set_status(500)
-            self.finish(f"JWT Found: {headers['userid-token']}")
+            self.finish(f"JWT Found: {headers[JWT_HEADER]}")
         else:
             self.finish('Kubeflow JWT is valid and not expired.')
 
